# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Handle pre-releases
#global alpha_version a31
%if 0%{?alpha_version:1}
%define alpha_url /alpha
%endif

# We can use file capabilities rather than setuid as we have rpm 4.7 or later
%global perms_cdda2wav %caps(cap_dac_override,cap_sys_admin,cap_sys_nice,cap_net_bind_service,cap_sys_rawio+ep)
%global perms_cdrecord %caps(cap_sys_resource,cap_dac_override,cap_sys_admin,cap_sys_nice,cap_net_bind_service,cap_ipc_lock,cap_sys_rawio+ep)
%global perms_readcd %caps(cap_dac_override,cap_sys_admin,cap_net_bind_service,cap_sys_rawio+ep)

Name:		cdrtools
Epoch:		10
Version:	3.01
Release:	5.0%{?alpha_version}.%{__distinit}%{__distvers}
Summary:	CD/DVD/BluRay command line recording software
License:	BSD-2-Clause AND CDDL-1.0 AND GPL-2.0-only AND LGPL-2.1-only
URL:		http://sourceforge.net/projects/cdrtools/
Source0:	http://downloads.sf.net/cdrtools%{?alpha_url}/%{name}-%{version}%{?alpha_version}.tar.bz2
Patch0:		cdrecord-default.patch
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	gettext-devel
BuildRequires:	glibc-common
BuildRequires:	libcap-devel
BuildRequires:	make
BuildRequires:	perl
BuildRequires:	sed

%description
A set of command line programs for preparing and recording CD/DVD/BluRay media.

%package -n cdrecord
Summary:	Creates an image of an ISO9660 file system
Requires:	%{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}
Provides:	wodim = %{epoch}:%{version}-%{release}

%description -n cdrecord
A set of command line programs for recording CD/DVD/BluRay media.

%package -n mkisofs
Summary:	Creates an image of an ISO9660 file system
Requires:	%{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}
Provides:	genisoimage = %{epoch}:%{version}-%{release}

%description -n mkisofs
Create hybrid ISO9660/JOLIET/HFS file systems with Rock Ridge attributes.

%package -n cdda2wav
Summary:	A CD-Audio Grabbing tool
Requires:	%{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}
Provides:	icedax = %{epoch}:%{version}-%{release}

%description -n cdda2wav
The most evolved CD-audio extraction program with paranoia support.

%package -n btcflash
Summary:	Firmware flash utility for BTC DRW1008 DVD+/-RW recorder
Requires:	%{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}

%description -n btcflash
This is a firmware flash utility for BTC DRW1008 DVD+/-RW recorders.

%package devel
Summary:	Development files for cdrtools
Requires:	%{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}

%description devel
This package provides the development files of the cdrtools package.

%package libs
Summary:	Libraries for cdrtools

%description libs
This package provides the shared libraries for cdrtools.

%prep
%setup -q
%patch -P 0 -p0 -b .cdrecord-default

# Use UTF-8 encoding everywhere rather than ISO-8859-1
for i in $(find . -name "*.c") $(find . -name "*.1") $(find . -name "*.8") \
	cdda2wav/{README,THANKS} cdrecord/README* BUILD ABOUT INSTALL \
	CONTRIBUTING Changelog COMPILE AN-* mkisofs/ChangeLog; do
	iconv -f iso-8859-1 $i -t utf-8 -o $i.new && mv -f $i.new $i
done

# Avoid RPATH
sed -i -e 's@-R$(INS_BASE)/lib -R/opt/schily/lib@@g' DEFAULTS/* DEFAULTS_ENG/*

%build
# Parallel build is still broken in 3.01 alpha 7
make \
	GMAKE_NOWARN=true \
	LINKMODE="dynamic" \
	RUNPATH= \
	CPPOPTX="%{optflags}" \
	COPTX="%{optflags} -DTRY_EXT2_FS -fno-strict-aliasing"

%install
make \
	GMAKE_NOWARN=true \
	LINKMODE="dynamic" \
	INS_BASE=%{_prefix} \
	INS_RBASE=/ \
	DESTDIR=%{buildroot} \
	install

# Remove files we don't want packaged
rm -rf %{buildroot}/usr/lib/lib*.a
rm -rf %{buildroot}/usr/lib/profiled
rm -rf %{buildroot}%{_docdir}
rm -rf %{buildroot}%{_mandir}/man3
rm -rf %{buildroot}%{_mandir}/man5

# Move libraries to the appropriate place on 64-bit arches
if [ %{_libdir} != %{_prefix}/lib ]; then
	mkdir -p %{buildroot}%{_libdir}
	mv %{buildroot}%{_prefix}/lib/lib*.so* %{buildroot}%{_libdir}/
fi

# Make sure permissions are right for libs
chmod 755 %{buildroot}%{_libdir}/lib*.so*

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig replaced by RPM File Triggers from Fedora 28
%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig
%endif

%files -n cdrecord
%doc cdrecord/README* ABOUT AN* Changelog* CONTRIBUTING START
%config(noreplace) /etc/default/cdrecord
%config(noreplace) /etc/default/rscsi
%{perms_cdrecord} %{_bindir}/cdrecord
%{_bindir}/scgcheck
%{_bindir}/scgskeleton
%{perms_readcd} %{_bindir}/readcd
%{_sbindir}/rscsi
%{_mandir}/man1/cdrecord.1*
%{_mandir}/man1/readcd.1*
%{_mandir}/man1/scgcheck.1*
%{_mandir}/man1/rscsi.1*
%{_mandir}/man1/scgskeleton.1*

%files -n btcflash
%{_mandir}/man1/btcflash.1*
%{_bindir}/btcflash

%files -n mkisofs
%license mkisofs/COPYING
%doc mkisofs/ChangeLog mkisofs/ChangeLog.mkhybrid mkisofs/RELEASE mkisofs/TODO mkisofs/README*
%{_bindir}/mkisofs
%{_bindir}/mkhybrid
%{_bindir}/isoinfo
%{_bindir}/devdump
%{_bindir}/isodump
%{_bindir}/isovfy
%{_bindir}/isodebug
%{_mandir}/man8/devdump.8*
%{_mandir}/man8/isodebug.8*
%{_mandir}/man8/isodump.8*
%{_mandir}/man8/isoinfo.8*
%{_mandir}/man8/isovfy.8*
%{_mandir}/man8/mkhybrid.8*
%{_mandir}/man8/mkisofs.8*
%{_prefix}/lib/siconv/

%files -n cdda2wav
%doc cdda2wav/FAQ cdda2wav/HOWTOUSE cdda2wav/NEEDED cdda2wav/TODO cdda2wav/THANKS cdda2wav/README
%{_bindir}/cdda2mp3
%{_bindir}/cdda2ogg
%{perms_cdda2wav} %{_bindir}/cdda2wav
%{_mandir}/man1/cdda2wav.1*
%{_mandir}/man1/cdda2mp3.1*
%{_mandir}/man1/cdda2ogg.1*

%files libs
%license COPYING GPL-2.0.txt LGPL-2.1.txt CDDL.Schily.txt
%{_libdir}/libcdrdeflt.so.1.*
%{_libdir}/libdeflt.so.1.*
%{_libdir}/libedc_ecc.so.1.*
%{_libdir}/libedc_ecc_dec.so.1.*
%{_libdir}/libfile.so.1.*
%{_libdir}/libfind.so.1.*
%{_libdir}/libhfs.so.1.*
%{_libdir}/libmdigest.so.1.*
%{_libdir}/libparanoia.so.1.*
%{_libdir}/librscg.so.1.*
%{_libdir}/libscg.so.1.*
%{_libdir}/libscgcmd.so.1.*
%{_libdir}/libschily.so.1.*
%{_libdir}/libsiconv.so.1.*

%files devel
%{_includedir}/scg/
%{_includedir}/schily/
%{_libdir}/libcdrdeflt.so
%{_libdir}/libdeflt.so
%{_libdir}/libedc_ecc.so
%{_libdir}/libedc_ecc_dec.so
%{_libdir}/libfile.so
%{_libdir}/libfind.so
%{_libdir}/libhfs.so
%{_libdir}/libmdigest.so
%{_libdir}/libparanoia.so
%{_libdir}/librscg.so
%{_libdir}/libscg.so
%{_libdir}/libscgcmd.so
%{_libdir}/libschily.so
%{_libdir}/libsiconv.so

%changelog
* Sun Jul  9 2023 aul Howarth <paul@city-fan.org> - 10:3.01-5.0
- Drop Obsoletes for old cdrkit tools, so users can choose between packages

* Wed Mar 29 2023 Paul Howarth <paul@city-fan.org> - 10:3.01-4.0
- Use SPDX-format license tag
- Avoid deprecated patch syntax
- Use %%license unconditionally

* Fri Mar  9 2018 Paul Howarth <paul@city-fan.org> - 10:3.01-3.0
- Drop ldconfig scriptlets (replaced by RPM File Triggers) from Fedora 28
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Can always use file attributes
  - Can always build-require gettext-devel

* Wed Aug  3 2016 Paul Howarth <paul@city-fan.org> - 10:3.01-2.0
- Fix FTBFS when perl is not in the minimal buildroot
- Specify all build requirements

* Tue Sep  1 2015 Paul Howarth <paul@city-fan.org> - 10:3.01-1.0
- Update to 3.01 final release
- Build with -fno-strict-aliasing

* Wed Aug  5 2015 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a31
- Update to 3.01 alpha release 31

* Wed Jul  8 2015 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a30
- Update to 3.01 alpha release 30

* Thu Jul  2 2015 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a29
- Update to 3.01 alpha release 29

* Thu Mar 26 2015 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a28
- Update to 3.01 alpha release 28

* Mon Feb  2 2015 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a27
- Update to 3.01 alpha release 27

* Thu Jan  8 2015 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a26
- Update to 3.01 alpha release 26

* Mon Oct 13 2014 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a25
- Update to 3.01 alpha release 25
- Upstream moved to sourceforge
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Wed Mar  5 2014 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a23
- Update to 3.01 alpha release 23

* Tue Jan 21 2014 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a22
- Update to 3.01 alpha release 22

* Thu Jan  9 2014 Paul Howarth <paul@city-fan.org> - 10:3.01-0.2.a21
- Merge some improvements from Simone Caronni (http://negativo17.org/cdrtools/)
  - Use file capabilities rather than setuid where possible (i.e. if we have
    rpm 4.7 or above)
  - Build using shared libraries and create -libs and -devel sub-packages

* Mon Jan  6 2014 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a21
- Update to 3.01 alpha release 21

* Wed Jan  1 2014 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a20
- Update to 3.01 alpha release 20

* Sun Nov 24 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a19
- Update to 3.01 alpha release 19

* Tue Oct 15 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a18
- Update to 3.01 alpha release 18

* Tue Aug  6 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a17
- Update to 3.01 alpha release 17

* Thu Jul 11 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a16
- Update to 3.01 alpha release 16

* Tue Jun 11 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a15
- Update to 3.01 alpha release 15

* Tue Apr 23 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a14
- Update to 3.01 alpha release 14

* Wed Feb 27 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a13
- Update to 3.01 alpha release 13

* Tue Feb 12 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a12
- Update to 3.01 alpha release 12

* Wed Jan  9 2013 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a11
- Update to 3.01 alpha release 11

* Tue Dec 18 2012 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a10
- Update to 3.01 alpha release 10

* Tue Dec  4 2012 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a09
- Update to 3.01 alpha release 9

* Mon Aug 20 2012 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a08
- Update to 3.01 alpha release 8

* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a07
- Update to 3.01 alpha release 7

* Mon Oct 17 2011 Paul Howarth <paul@city-fan.org> - 10:3.01-0.1.a06
- Import from Simone Caronni's package (see history at #507108)
- Update to 3.01 alpha release 6
- Drop devel package
- Disable parallel build, which has broken since alpha 5
- Replace gettext-devel buildreq with /usr/share/aclocal/iconv.m4, for
  support of ancient distributions prior to gettext/gettext-devel split

* Mon Jun 06 2011 Simone Caronni <negativo17@gmail.com> - 10:3.01-a05.1
- Updated

* Mon May 09 2011 Simone Caronni <negativo17@gmail.com> - 10:3.01-a04.1
- Updated

* Tue Mar 15 2011 Simone Caronni <negativo17@gmail.com> - 10:3.01-a03.1
- Updated

* Tue Feb 08 2011 Simone Caronni <negativo17@gmail.com> - 10:3.01-a02.1
- Updated

* Fri Dec 10 2010 Simone Caronni <negativo17@gmail.com> - 10:3.01-a01.2
- Fixed rpmlint errors

* Tue Dec 07 2010 Simone Caronni <negativo17@gmail.com> - 10:3.01-a01.1
- Updated to 3.01a01

* Mon Nov 29 2010 Simone Caronni <negativo17@gmail.com> - 10:3.00-4
- Remove linker paths
- Add setuid for cdda2wav, readcd and rscsi

* Fri Nov 26 2010 Roman Rakus <rrakus@redhat.com> - 10:3.00-2
- Fixed some rpmlint errors and warnings

* Thu Nov 25 2010 Simone Caronni <negativo17@gmail.com> - 10:3.00-1
- First build:
  - Patch default device to match standard Fedora behaviour: the first cdrom
    device set up by udev can be used without parameters
  - Recode everything from ISO-8859-1 to UTF-8
  - Obsoletes cdrkit but provides its components for anaconda, etc.
  - Epoch set to 10 to avoid loop problems with yum
